@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package CPAN::Meta;
 BEGIN {
-  $CPAN::Meta::VERSION = '2.110390';
+  $CPAN::Meta::VERSION = '2.110420';
 }
 # ABSTRACT: the distribution metadata for a CPAN dist
 
@@ -192,6 +192,7 @@ sub save {
   my ($self, $file, $options) = @_;
 
   my $version = $options->{version} || '2';
+  my $layer = $] ge '5.008001' ? ':utf8' : '';
 
   if ( $version ge '2' ) {
     carp "'$file' should end in '.json'"
@@ -203,9 +204,9 @@ sub save {
   }
 
   my $data = $self->as_string( $options );
-
-  open my $fh, ">", $file
+  open my $fh, ">$layer", $file
     or die "Error opening '$file' for writing: $!\n";
+
   print {$fh} $data;
   close $fh
     or die "Error closing '$file': $!\n";
@@ -318,7 +319,7 @@ sub as_string {
   my ($data, $backend);
   if ( $version ge '2' ) {
     $backend = Parse::CPAN::Meta->json_backend();
-    $data = $backend->new->utf8->pretty->canonical->encode($struct);
+    $data = $backend->new->pretty->canonical->encode($struct);
   }
   else {
     $backend = Parse::CPAN::Meta->yaml_backend();
@@ -348,7 +349,7 @@ CPAN::Meta - the distribution metadata for a CPAN dist
 
 =head1 VERSION
 
-version 2.110390
+version 2.110420
 
 =head1 SYNOPSIS
 
@@ -445,7 +446,8 @@ the given JSON string.  In other respects it is identical to C<load_file()>.
   $meta->save($distmeta_file, \%options);
 
 Serializes the object as JSON and writes it to the given file.  The only valid
-option is C<version>, which defaults to '2'.
+option is C<version>, which defaults to '2'. On Perl 5.8.1 or later, the file
+is saved with UTF-8 encoding.
 
 For C<version> 2 (or higher), the filename should end in '.json'.  L<JSON::PP>
 is the default JSON backend. Using another JSON backend requires L<JSON> 2.5 or
@@ -456,8 +458,8 @@ For C<version> less than 2, the filename should end in '.yml'.
 L<CPAN::Meta::Converter> is used to generate an older metadata structure, which
 is serialized to YAML.  CPAN::Meta::YAML is the default YAML backend.  You may
 set the C<$ENV{PERL_YAML_BACKEND}> to a supported alternative backend, though
-this is not recommended due to subtle incompatibilities between YAML parsers
-on CPAN.
+this is not recommended due to subtle incompatibilities between YAML parsers on
+CPAN.
 
 =head2 meta_spec_version
 
@@ -525,17 +527,18 @@ of the specification and returned.  For example:
 
   my $string = $meta->as_string( \%options );
 
-This method returns a serialized copy of the object's metadata.
-reference.  It takes an optional hashref of options.  If the hashref contains
-a C<version> argument, the copied metadata will be converted to the version
-of the specification and returned.  For example:
+This method returns a serialized copy of the object's metadata as a character
+string.  (The strings are B<not> UTF-8 encoded.)  It takes an optional hashref
+of options.  If the hashref contains a C<version> argument, the copied metadata
+will be converted to the version of the specification and returned.  For
+example:
 
   my $string = $meta->as_struct( {version => "1.4"} );
 
-For C<version> greater than or equal to 2, the string will be serialized
-as JSON.  For C<version> less than 2, the string will be serialized as YAML.
-In both cases, the same rules are followed as in the C<save()> method for
-choosing a serialization backend.
+For C<version> greater than or equal to 2, the string will be serialized as
+JSON.  For C<version> less than 2, the string will be serialized as YAML.  In
+both cases, the same rules are followed as in the C<save()> method for choosing
+a serialization backend.
 
 =head1 STRING DATA
 
